﻿<?php
class Coordinador_model extends CI_Model {

	function __construct(){
		parent::__construct();	
		$this->load->database();   
		
	}

	/**
	 * Lista de masteres asociados a un coordinador para un año academico y convocatoria
	 * @param $ano_academico
     * @param $convocatoria
     * @param $user 
	 * @return unknown_type
	 */
	function listarMasteres($user,$ano_academico, $convocatoria){
	
	    $sqlquery = "SELECT c.cod_plan, b.descripcion , d.plazas_ofertadas,d.bloqueado,count(distinct a.dni_pasaporte) as n_solicitudes
		             FROM   pm_plan d, p_plan b,pm_coordinadores  c
					  LEFT JOIN pm_det_preinscripcion a ON (  a.ano_academico = c.ano_academico and
                            a.convocatoria = c.convocatoria and
                            a.cod_plan_opc = c.cod_plan	and
                            a.dni_pasaporte not in (select dni_pasaporte
                                                     from pm_excluidos e
                                                    where e.ano_academico = a.ano_academico and
                                                         e.convocatoria  = a.convocatoria  )) 	
					 WHERE  c.dni_pasaporte = ? and
					        c.ano_academico = ? and
							c.convocatoria = ? and
							c.cod_plan = b.codigo_plan  and
							c.ano_academico = d.ano_academico and
							c.convocatoria = d.convocatoria and
							c.cod_plan = d.cod_plan
					 GROUP BY c.cod_plan, b.descripcion	,d.plazas_ofertadas,d.bloqueado
					 ORDER BY c.cod_plan";
					 
		$query=$this -> db ->query($sqlquery,array($user,$ano_academico,$convocatoria));		
		
		 	
	 	if ($query->num_rows()==1){
	 		log_message('info',">>Coordinador de 1 master::".$user);
	 	}else{
	 		log_message('info',">>Coordinador de varios master::".$user);
	 	}
	 		 	
		return $query->result();
	}
	
	
	/**
	 *  Obtengo master asociado de un coordinador
	 * @param $ano_academico
     * @param $convocatoria
     * @param $user 
	 * @return unknown_type
	 */
    function getMasterAsociado($user,$ano_academico, $convocatoria)
    {
	
		log_message('debug','llamo a getMasterAsociado');
		
		 $sqlquery = "SELECT distinct a.cod_plan, b.descripcion 
		             FROM  pm_coordinadores  a, p_plan b ,  pm_plan d
					 WHERE  a.dni_pasaporte = ? and
					        a.ano_academico = ? and
							a.convocatoria = ? and
							a.cod_plan = b.codigo_plan and
                            a.ano_academico = d.ano_academico and
							a.convocatoria = d.convocatoria and
							a.cod_plan = d.cod_plan		";
		
    	//log_message('debug',$sqlquery);		
		$query=$this -> db ->query($sqlquery,array($user,$ano_academico,$convocatoria));		
		
		
		return $query->row();
		
	
	}
	
	
	/**
	 *  Obtengo descripcion de un plan
	 * @param $plan
	 * @return unknown_type
	 */
	function getDescripcionPlan($plan)
    {
	
		log_message('debug','llamo a getDescripcionPlan');
		
        $sqlquery=" SELECT distinct descripcion FROM p_plan  WHERE codigo_plan = ?";
		
   	    //log_message('debug',$sqlquery);		
		$query=$this -> db ->query($sqlquery,array($plan));		
		
		
        $valor = $query->row();
  		return $valor->DESCRIPCION;
	
	}
	
		
	 /**
	 * Hace una consulta para saber si existe solicitudes en lista de espera en el plan 
	 * devuelve 0 o 1 filas
	 * @param $plan debe ser distinto de null
     * @param $ano_academico
     * @param $convocatoria
	 * @return unknown_type
	 */
	function existeListaEspera($plan, $ano_academico, $convocatoria){
				
	    $sqlquery="SELECT distinct cod_plan_opc
			 FROM  pm_det_preinscripcion a,
				   pm_cab_preinscripcion	c					      
			 WHERE  a.cod_plan_opc = ? and
					a.ano_academico = ? and
					a.convocatoria = ? and							
					a.ano_academico = c.ano_academico and
					a.convocatoria = c.convocatoria and
					a.dni_pasaporte = c.dni_pasaporte and	
					a.preadmitido = 'E' and	
                    ordenlistaespera != 0 and					
					a.dni_pasaporte not in (select dni_pasaporte
											 from pm_excluidos e
											where e.ano_academico = a.ano_academico and
												 e.convocatoria  = a.convocatoria  )  ";	 	
		
		$query=$this -> db ->query($sqlquery,array($plan,$ano_academico,$convocatoria));
	 	
	 	if ($query->num_rows()==1){
	 		log_message('info',">>Existe lista espera::".$plan);
	 	}else{
	 		log_message('info',">>NO existe lista espera::".$plan);
	 	}
	 	
	 	return $query->row();
		
	}
	
	
	
	/**
	 * Lista de solicitudes en lista de espera para un plan en año academico y convocatoria
     * @param $plan 
	 * @param $ano_academico
     * @param $convocatoria
	 * @return unknown_type
	 */
	function listarListaEspera($plan,$ano_academico, $convocatoria){
	
	    $sqlquery = "SELECT (a.ordenlistaespera -1) as ordenlistaespera,a.dni_pasaporte, 
		             upper(nomb_alumno) as nomb_alumno, upper(ape1_alumno) as ape1_alumno,
                     upper(ape2_alumno) as ape2_alumno		
		             FROM   pm_det_preinscripcion a, pm_solicitantes b					 			    
					 WHERE  a.cod_plan_opc = ? and
					        a.ano_academico = ? and
							a.convocatoria = ? and
							a.ano_academico = b.ano_academico and
							a.convocatoria = b.convocatoria and
							a.dni_pasaporte = b.dni_pasaporte and
							a.preadmitido = 'E' and
                            a.dni_pasaporte not in (select dni_pasaporte
                                                     from pm_excluidos e
                                                    where e.ano_academico = a.ano_academico and
                                                         e.convocatoria  = a.convocatoria  ) and
							a.ordenlistaespera != 0
					ORDER BY ordenlistaespera ";									 
					 
		$query=$this -> db ->query($sqlquery,array($plan,$ano_academico,$convocatoria));			
			 		 	
		return $query->result();
	}
	
	
	
	
	/**
	 * Modifica lista de espera de un plan
	 * @param $ano_academico
	 * @param $convocatoria
	 * @param $plan
	 * @param $dni_pasaporte
	 * @param $data
	 * @return unknown_type
	 */	
	function modificarListaEspera($ano_academico, $convocatoria,$plan,$dni_pasaporte, $data)
	{				
		
		return $this->db->update('PM_DET_PREINSCRIPCION', $data, array('COD_PLAN_OPC'=>$plan,'ANO_ACADEMICO'=>$ano_academico,'CONVOCATORIA'=>$convocatoria, 'DNI_PASAPORTE'=>$dni_pasaporte));
  	}
	
	
	
   /**
	 * Listado de alumnos preinscritos para un plan en año academico y convocatoria para generar PDF
     * @param $plan 
	 * @param $ano_academico
     * @param $convocatoria
	 * @return unknown_type
	 */
	function ListaSolicitudes($ano_academico, $convocatoria,$plan){
	
	    $sqlquery = "SELECT DISTINCT b.dni_pasaporte, 
						 upper(b.ape1_alumno) ||' '|| upper(b.ape2_alumno) || ',' || upper(b.nomb_alumno) as alumno,
						 upper(b.nomb_alumno) as nomb_alumno, upper(b.ape1_alumno) as ape1_alumno,
						 upper(b.ape2_alumno) as ape2_alumno,a.opcion, 
						 CASE WHEN c.cod_estudios_mec = '90990000000' THEN c.otro_estudio_origen
							  ELSE e.des_codigo_mec
						 END as des_codigo_mec,         
						 CASE WHEN c.cod_estudios_mec = '90990000000' THEN c.otra_universidad_origen
							  ELSE u.denominacion
						 END as des_universidad, preadmitido,
					     nvl(s.estado, '--------------') as estado
		             FROM   pm_det_preinscripcion a, pm_solicitantes b, 
					       pm_cab_preinscripcion	c
					       LEFT JOIN p_estudios_mec e ON (  c.cod_estudios_mec= e.codigo_mec)
						   LEFT JOIN p_universidades_mec u ON ( c.universidad_origen = u.cod_universidad_mec)
						   LEFT JOIN pm_estado s ON (  c.estado_solicitud = s.id_estado and c.ano_academico = s.ano_academico and
                                           c.convocatoria = s.convocatoria)
					 WHERE  a.cod_plan_opc = ? and
					        a.ano_academico = ? and
							a.convocatoria = ? and
							a.ano_academico = b.ano_academico and
							a.convocatoria = b.convocatoria and
							a.dni_pasaporte = b.dni_pasaporte and
							a.ano_academico = c.ano_academico and
							a.convocatoria = c.convocatoria and
							a.dni_pasaporte = c.dni_pasaporte and							
                            a.dni_pasaporte not in (select dni_pasaporte
                                                     from pm_excluidos e
                                                    where e.ano_academico = a.ano_academico and
                                                         e.convocatoria  = a.convocatoria  ) 
					ORDER by b.dni_pasaporte ";	

	
		$query=$this -> db ->query($sqlquery,array($plan,$ano_academico,$convocatoria));			
			 		 	
		return $query->result();
	}
	
	
	/**
	 * Modifica el detalle del solicitante para un plan, ano academico y convocatoria
	 * @param $ano_academico
	 * @param $convocatoria
	 * @param $dni_pasaporte
	 * @param $plan
	 * @param $data
	 * @return unknown_type
	 */	
	function modificarDetalle($ano_academico, $convocatoria,$dni_pasaporte,$plan,$data)
	{				
				
		return $this->db->update('PM_DET_PREINSCRIPCION', $data, array('COD_PLAN_OPC'=>$plan,'DNI_PASAPORTE'=>$dni_pasaporte,'ANO_ACADEMICO'=>$ano_academico,'CONVOCATORIA'=>$convocatoria));
  	}
		
		
		
		
	/**
	 *  Obtengo el siguiente orden de espera para un plan
	 * @param $ano_academico
	 * @param $convocatoria
	 * @param $plan
	 * @return unknown_type
	 */
    function getSiguienteListaEspera($ano_academico, $convocatoria,$plan)
    {
	
		log_message('debug','llamo a getUltimaListaEspera');
		
        $sqlquery="SELECT (max(ordenlistaespera) +1) as n_lista_espera
		             FROM  pm_det_preinscripcion a,
					       pm_cab_preinscripcion	c					      
					 WHERE  a.cod_plan_opc = ? and
					        a.ano_academico = ? and
							a.convocatoria = ? and							
							a.ano_academico = c.ano_academico and
							a.convocatoria = c.convocatoria and
							a.dni_pasaporte = c.dni_pasaporte and	
                            a.preadmitido = 'E' and							
                            a.dni_pasaporte not in (select dni_pasaporte
                                                     from pm_excluidos e
                                                    where e.ano_academico = a.ano_academico and
                                                         e.convocatoria  = a.convocatoria  )  ";
		
   	    //log_message('debug',$sqlquery);
        $query=$this -> db ->query($sqlquery,array($plan,$ano_academico,$convocatoria));			
		
		
        $valor = $query->row();
  		return $valor->N_LISTA_ESPERA;
	
	}
		
	/**
	 *  Obtengo numero de plazas ofertadas para un plan en un año y convocatoria
	 * @param $plan
	  * @param $ano_academico
	 * @param $convocatoria
	 * @return unknown_type
	 */
	function getPlazasOfertadas($plan, $ano_academico, $convocatoria)
    {
	
		log_message('debug','llamo a getPlazasOfertadas');
		
        $sqlquery=" SELECT plazas_ofertadas FROM pm_plan 
            		WHERE  cod_plan = ? and
					       ano_academico = ? and
						   convocatoria = ? ";
		
   	    //log_message('debug',$sqlquery);		
		$query=$this -> db ->query($sqlquery,array($plan,$ano_academico,$convocatoria));
		
		
        $valor = $query->row();
  		return $valor->PLAZAS_OFERTADAS;
	
	}	
	
	
	
	/**
	 * Listado de alumnos admitidos/lista espera para un plan en año academico y convocatoria para modificar nodo
     * @param $plan 
	 * @param $ano_academico
     * @param $convocatoria
	 * @return unknown_type
	 */
	function listarPreadNodo($plan,$ano_academico, $convocatoria){
	
	    $sqlquery = "SELECT DISTINCT b.dni_pasaporte as dni_pasaporte, 
		             upper(b.ape1_alumno) ||' '|| upper(b.ape2_alumno) || ',' || upper(b.nomb_alumno) as alumno,
		             a.opcion, 
					 a.nodo_opc, 
					 CASE WHEN c.cod_estudios_mec = '90990000000' THEN c.otro_estudio_origen
                          ELSE e.des_codigo_mec
                     END as des_codigo_mec,         
                     CASE WHEN c.cod_estudios_mec = '90990000000' THEN c.otra_universidad_origen
                          ELSE u.denominacion
                     END as des_universidad,
					 nvl(s.estado, '--------------') as estado
		             FROM   pm_det_preinscripcion a, pm_solicitantes b, 
					       pm_cab_preinscripcion	c
					       LEFT JOIN p_estudios_mec e ON (  c.cod_estudios_mec= e.codigo_mec)
						   LEFT JOIN p_universidades_mec u ON ( c.universidad_origen = u.cod_universidad_mec)
						   LEFT JOIN pm_estado s ON (  c.estado_solicitud = s.id_estado and c.ano_academico = s.ano_academico and
                                           c.convocatoria = s.convocatoria)
					 WHERE  a.cod_plan_opc = ? and
					        a.ano_academico = ? and
							a.convocatoria = ? and
							a.ano_academico = b.ano_academico and
							a.convocatoria = b.convocatoria and
							a.dni_pasaporte = b.dni_pasaporte and
							a.ano_academico = c.ano_academico and
							a.convocatoria = c.convocatoria and
							a.dni_pasaporte = c.dni_pasaporte and
							a.preadmitido in ( 'S', 'E') and
                            a.dni_pasaporte not in (select dni_pasaporte
                                                     from pm_excluidos e
                                                    where e.ano_academico = a.ano_academico and
                                                         e.convocatoria  = a.convocatoria  ) 
					ORDER by alumno asc ";	

	
		$query=$this -> db ->query($sqlquery,array($plan,$ano_academico,$convocatoria));			
			 		 	
		return $query->result();
	}
	
	
	
	/**
	 * Hace consulta sobre tabla pm_coordinadores
     * @param $ano_academico
	 * @param $convocatoria
	 * @return unknown_type
	 */
	function getCoordinadores($ano_academico,$convocatoria){
				
		$sqlquery="SELECT *
		          FROM pm_coordinadores
				  WHERE ano_academico = ? and convocatoria = ? ORDER BY dni_pasaporte, cod_plan";
	 	
		
		$query=$this -> db ->query($sqlquery,array($ano_academico,$convocatoria));
	 	
	 	if ($query->num_rows() > 1){
	 		log_message('info',">>Existen pm_coordinadores::".$ano_academico);
	 	}else{
	 		log_message('info',">>NO existe pm_coordinadores::".$ano_academico);
	 	}
	 	
	 	return $query->result();
		
	}
	
	
	/**
	 * Inserta un nuevo coordinador y plan en tabla pm_coordinadores
	 * @param $data
	 * @return unknown_type
	 */	
	function insertarCoordinador($data)
	{				
	   	
		return $this->db->insert('PM_COORDINADORES', $data);
  	}

	/**
	 * Modifica un coordinador de la tabla pm_coordinadores
	 * @param $ano_academico
	 * @param $convocatoria
	 * @param $dni
	 * @param $plan
	 * @param $data	
	 * @return unknown_type
	 */	
	function modificarCoordinador($ano_academico, $convocatoria,$dni_pasaporte, $plan,$data)
	{			
        log_message('debug',"modifico coordinador");		
		return $this->db->update('PM_COORDINADORES', $data, array('DNI_PASAPORTE'=>$dni_pasaporte,'COD_PLAN'=>$plan,'ANO_ACADEMICO'=>$ano_academico,'CONVOCATORIA'=>$convocatoria));
  	}
	
	
	/**
	 * Borra un coordindor y plan de la tabla pm_coordinadores
	 * @param $ano_academico
	 * @param $convocatoria
	 * @param $dni_pasaporte
	 * @param $plan
	 * @return unknown_type
	 */	
	 function deleteCoordinador($anoacademico,$convocatoria,$dni_pasaporte,$plan)
    {      
		return $this->db->delete('PM_COORDINADORES', array('ANO_ACADEMICO'=>$anoacademico, 'CONVOCATORIA'=>$convocatoria, 'DNI_PASAPORTE'=>$dni_pasaporte,'COD_PLAN'=>$plan));       
    }
	
	
	/**
	 * Nos devuelve el valor de bloqueo
	 * devuelve 0 o 1 filas
	 * @param $ano_academico
	 * @param $convocatoria
	 * @param $user 
	 * @return unknown_type
	 */
	function getBloqueo($ano_academico, $convocatoria,$plan){
				
		$sqlquery="SELECT bloqueado
		          FROM   pm_plan 				 
				  WHERE ano_academico = ? and
						convocatoria = ? and
						cod_plan = ? ";
		
		$query=$this -> db ->query($sqlquery,array($ano_academico,$convocatoria,$plan));
	 	
	 	if ($query->num_rows()==1){
	 		log_message('info',">>Master bloqueado :".$plan);
	 	}else{
	 		log_message('info',">>Master NO bloqueado::".$plan);
	 	}
	 		
	 	return $query->row()->BLOQUEADO;
		
	}
	
	/**
	 *  Obtengo datos de un coordinador para un dni y plan (tabla pm_coordinadores)
	 * @param $ano_academico
	 * @param $convocatoria
	 * @param $dni_pasaporte
	 * @param $plan
	 * @return unknown_type
	 */
    function getdatosCoordinadorPlan($ano_academico, $convocatoria,$dni_pasaporte,$plan)
    {
	
		log_message('debug','llamo a getdatosCoordinador');
		
		$sqlquery=" SELECT  *				              					
		            FROM pm_coordinadores                   
					WHERE ano_academico = ? and convocatoria = ? and
   					      dni_pasaporte = ? and cod_plan = ?";
					       
		
    	//log_message('debug',$sqlquery);		
		$query=$this -> db ->query($sqlquery,array($ano_academico, $convocatoria,$dni_pasaporte,$plan));
		
		return $query->row();
		
	
	}
	
	/**
	 *  Obtengo datos de un coordinador para un dni (tabla pm_coordinadores)
	 * @param $ano_academico
	 * @param $convocatoria
	 * @param $dni_pasaporte
	 * @return unknown_type
	 */
    function getdatosCoordinador($ano_academico, $convocatoria,$dni_pasaporte)
    {
	
		log_message('debug','llamo a getdatosCoordinador');
		
		$sqlquery=" SELECT  distinct nombre || ' ' || apellido1 || ' ' || apellido2 as nombre, email			              					
		            FROM pm_coordinadores                   
					WHERE ano_academico = ? and convocatoria = ? and
   					      dni_pasaporte = ? ";
					       
		
    	//log_message('debug',$sqlquery);		
		$query=$this -> db ->query($sqlquery,array($ano_academico, $convocatoria,$dni_pasaporte));
		
		return $query->row();
		
	
	}
	
}
?>