﻿<?php
class Datosacademicos_model extends CI_Model {

	function __construct(){
		parent::__construct();
		$this->load->database();   
	}

	/**
	 * Hace una consulta para saber si ya ha introducido los datos academicos de solicitud para el año y convocatoria en curso
	 * devuelve 0 o 1 filas
	 * @param $user debe ser distinto de null
     * @param $ano_academico
     * @param $convocatoria
	 * @return unknown_type
	 */
	function existeDatosAcademicos($user, $ano_academico, $convocatoria){
		
		$sqlquery="SELECT dni_pasaporte 
		           FROM pm_cab_preinscripcion 
				   WHERE dni_pasaporte = ? and
				         ano_academico =  ? and
						 convocatoria = ? ";
	 	
		//('debug', $sqlquery);
		
		$query=$this -> db ->query($sqlquery,array($user,$ano_academico,$convocatoria));
	 	return $query->row();
	
	}
	
 
	
		
	/**
	 * Inserta un datos academicos
	 * @param $data
	 * @return unknown_type
	 */	
	function insertarDatosAcademicos($data)
	{				
		$this->db->set('FECHA_PAGO',"to_date('".$data['FECHA_PAGO']."','dd/mm/yyyy')",false);

		unset($data['FECHA_PAGO']);	
		
		return $this->db->insert('PM_CAB_PREINSCRIPCION', $data);
  	}
	

	
	
	/**
	 * Modifica datos academicos de un  solicitante 
	 * @param $ano_academico
	 * @param $convocatoria
	 * @param $dni_pasaporte
	 * @param $data
	 * @return unknown_type
	 */	
	function modificarDatosAcademicos($ano_academico, $convocatoria,$dni_pasaporte,$data)
	{	

        if (isset($data['FECHA_PAGO'])){
			$this->db->set('FECHA_PAGO',"to_date('".$data['FECHA_PAGO']."','dd/mm/yyyy')",false);
			unset($data['FECHA_PAGO']);
		}	
	
		
		return $this->db->update('PM_CAB_PREINSCRIPCION', $data, array('DNI_PASAPORTE'=>$dni_pasaporte,'ANO_ACADEMICO'=>$ano_academico,'CONVOCATORIA'=>$convocatoria));
  	}
				
		
	
	/**
	 *  Obtengo datos academicos para un dni en el año y convocatoria actual
	 * @param $ano_academico
	 * @param $convocatoria
	 * @param $dni_pasaporte
	 * @return unknown_type
	 */
    function getdatosAcademicos($ano_academico, $convocatoria,$dni_pasaporte)
    {
	
		log_message('debug','llamo a getDatosAcademicos');
		
    	 $sqlquery =" SELECT distinct  a.*,to_char(a.fecha_pago, 'dd/mm/yyyy') as fecha_pago,
                		 '' as acceso_otros_estudios,b.des_codigo_mec as des_estudios_mec 
		              FROM pm_cab_preinscripcion a 
					  LEFT JOIN  p_estudios_mec b  ON  a.cod_estudios_mec = b.codigo_mec 
					  WHERE a.dni_pasaporte = ? and a.ano_academico = ? and a.convocatoria = ? "; 
		
    	//log_message('debug',$sqlquery);		
		$query=$this -> db ->query($sqlquery,array($dni_pasaporte,$ano_academico,$convocatoria));
		
		return $query->row();	
	
	}
	
	
	/**
	 * Lista de universidades excepto  Extranjera
	 * @return unknown_type
	 */
	function listarUniversidades(){
	
	    $sqlquery = "SELECT cod_universidad_mec, denominacion
		             FROM p_universidades_mec 
					 WHERE cod_universidad_mec != '90' 
					 ORDER BY denominacion";
		$query = $this->db->query($sqlquery);
		
		return $query->result();		
	}
	
	/**
	 * Lista de universidades excepto  Extranjera y universidad de valladolid
	 * @return unknown_type
	 */
	function listarUniversidadesSinUva(){
	
	    $sqlquery = "SELECT cod_universidad_mec, denominacion
		             FROM p_universidades_mec 
					 WHERE cod_universidad_mec not in ( '90', '19') 
					 ORDER BY denominacion";
		$query = $this->db->query($sqlquery);
		
		return $query->result();		
	}
	
	
	/**
	 * Lista de estudios origen en funcion de la univesidad y tipo de estudio seleccionado
	 * @param $universidad
	 * @param $tipoestudio
	 * @return unknown_type
	 */
	function listarEstudiosOrigen($universidad, $tipoestudio){
	
	    if ($tipoestudio == '1') { //grados
		     if ($universidad == '95'){ // CENTRO ADSCRITOS-UVA
			      $sqlquery = "SELECT  distinct codigo_mec, des_codigo_mec  
			              FROM p_estudios_mec 
						  WHERE codigo_mec <>'90990000000' and 
						        decode(universidad,'95', '19',universidad) = '19' and codigo_mec in (2500465, 2500464, 2502313) and 
			 					tipo_estudio ='5' ORDER BY des_codigo_mec";					
			 }					
			 else {					
			      $sqlquery = "SELECT  distinct codigo_mec, des_codigo_mec  
			              FROM p_estudios_mec 
						  WHERE codigo_mec <>'90990000000' and 
						        universidad='".$universidad."' and 
								tipo_estudio ='5' ORDER BY des_codigo_mec";
			}  
	  }
	  else {  //Licenciado, Ingeniero, Arquitecto, Diplomado, Ingeniero Técnico y Arquitecto Técnico
	  	 if ($universidad == '93'){ //universidad Diversos Organismos oficiales
	   	    $sqlquery = "SELECT  distinct codigo_mec, des_codigo_mec  FROM  p_estudios_mec WHERE  codigo_mec ='99999900000' ";
	     }
	     elseif ($universidad == '94'){ //universidad Ministerio de Educación (Homologación)
	   	    $sqlquery ="SELECT distinct codigo_mec, des_codigo_mec 
			           FROM p_estudios_mec  
					   WHERE  codigo_mec not in ('90990000000','60500000000','60250000000','00001234567','00001234568',
                                                  '30280200000','00000000002') and
					          tipo_estudio <> 5 and tipo_estudio <> 6 
	   	               UNION
					   SELECT codigo_mec, des_codigo_mec 
					   FROM p_estudios_mec  
					   WHERE codigo_mec in ('90000000561', '90000000560') 
					   ORDER BY des_codigo_mec ";
	     }
	     else { 
			  
			   $sqlquery ="SELECT distinct codigo_mec, des_codigo_mec 
			               FROM p_estudios_mec  
						   WHERE codigo_mec not in ('90990000000','60500000000','60250000000','00001234567','00001234568',
                                                  '30280200000','00000000002') and
						         tipo_estudio <> 5 and tipo_estudio <> 6 
						   ORDER BY des_codigo_mec";
			 }  
		}
	    
		$query = $this->db->query($sqlquery);
		
		return $query->result();		
	}
	
	
	/**
	 *  Obtengo el tipo de estudio dato un codigo de estudios
	 * @param $dni_pasaporte
	 * @return unknown_type
	 */
    function getTipoEstudio($cod_estudios)
    {
	
		log_message('debug','llamo a getTipoEstudio');
		
        $sqlquery=" SELECT distinct tipo_estudio FROM p_estudios_mec  WHERE  codigo_mec = ?";
		
   	    //log_message('debug',$sqlquery);		
		$query=$this -> db ->query($sqlquery,array($cod_estudios));
		
        $valor = $query->row();
  		return $valor->TIPO_ESTUDIO;
	
	}
	
	
	
	/**
	 * Lista de expedientes titulados en la uva para un dni (considerando titulados los que tiene fecha de pago)
     * @param $dni_pasaporte
	 * @return unknown_type
	 */
	function listarExpedientesTitulados($dni_pasaporte){
	
 	    $sqlquery = "SELECT DISTINCT e.des_codigo_mec , c.cod_estudios_mec, to_char(t.fecha_pago, 'dd/mm/yyyy') as fecha_pago
					 FROM p_cab_expedientes c, p_titulados t, p_estudios_mec e
                     WHERE c.dni_pasaporte = ? AND 
					       c.num_expediente = t.num_expediente  AND 
						   e.codigo_mec = c.cod_estudios_mec  AND
						   t.fecha_pago is not null
				     ORDER BY e.des_codigo_mec ";
					 
		
		$query=$this -> db ->query($sqlquery,array($dni_pasaporte));
		
		return $query->result();		
	}
		
		
		
	/**
	 *  Obtengo descripcion de un codigo mec
	 * @param $estudio
	 * @return unknown_type
	 */
    function getDescripcionEstudio($estudio)
    {
	
		log_message('debug','llamo a getDescripcionEstudio');
		
        $sqlquery=" SELECT distinct des_codigo_mec  FROM p_estudios_mec  WHERE  codigo_mec = ?";
		
    	//log_message('debug',$sqlquery);		
		$query=$this -> db ->query($sqlquery,array($estudio));
		
		$valor = $query->row();
  		return $valor->DES_CODIGO_MEC;
	
	
	}	
	
	/**
	 *  Obtengo fecha pago de un codigo mec de un dni_pasaporte
	 * @param $dni_pasaporte
	 * @param $estudio
	 * @return unknown_type
	 */
    function getFechaPagoEstudio($dni_pasaporte, $estudio)
    {
	
		log_message('debug','llamo a getFechaPagoEstudio');
		
        $sqlquery="SELECT DISTINCT  to_char(t.fecha_pago, 'dd/mm/yyyy') as fecha_pago 
					 FROM p_cab_expedientes c, p_titulados t
                     WHERE c.dni_pasaporte = ? AND c.num_expediente = t.num_expediente 
					    AND  c.cod_estudios_mec = ? AND t.fecha_pago is not null";
						
							
		
       // log_message('debug',$sqlquery);		
		$query=$this -> db ->query($sqlquery,array($dni_pasaporte,$estudio));
		
		$valor = $query->row();
  		return $valor->FECHA_PAGO;
	
	
	}
	
	
	
	
	/**
	 * Hace una consulta para saber si es los datos academicos esta o no bloqueados 
	 * devuelve 0 o 1 filas
	 * @param $ano_academico
	 * @param $convocatoria
	 * @param $user 
	 * @return unknown_type
	 */
	function datosAcademicosBloqueado($ano_academico, $convocatoria,$user){
				
		$sqlquery="SELECT dni_pasaporte 
		           FROM pm_cab_preinscripcion 
				   WHERE dni_pasaporte = ? and 
				         ano_academico = ? and 
						 convocatoria = ? and 
						 nivel_bloqueo != 0 ";
		
		$query=$this -> db ->query($sqlquery,array($user,$ano_academico,$convocatoria));
	 	
	 	if ($query->num_rows()==1){
	 		log_message('info',">>Datos Academicos bloqueados :".$user);
	 	}else{
	 		log_message('info',">>Datos Academicos NO bloqueados::".$user);
	 	}
	 	
	 	return $query->row();
		
		
	}
	
	
	
	/**
	 * Devuelve la descripcion de un codigo de universidad	
	 * @param $cod_universidad_mec
	 * @return unknown_type
	 */
	function getDesUniversidad($cod_universidad_mec){
	
	    $sql = "SELECT cod_universidad_mec, denominacion
		             FROM p_universidades_mec WHERE cod_universidad_mec=?";
		
		$query=$this -> db ->query($sql,array($cod_universidad_mec));
		return $query->row()->DENOMINACION;		
	}
	
	
	
	/**
	 * Devuelve la fecha de nacimiento + 20 años
	 * @param $ano_academico
	 * @param $convocatoria
	 * @param $user 
	 * @return unknown_type
	 */
	function getFechaNacim20Años($ano_academico, $convocatoria,$user){
	
		$sqlquery="SELECT to_char(add_months(fecha_nac_alumno,12*20),'dd/mm/yyyy')  as fecha 
		           FROM pm_solicitantes 
				   WHERE dni_pasaporte = ? and 
				         ano_academico = ? and 
						 convocatoria = ?  ";
		
		$query=$this -> db ->query($sqlquery,array($user,$ano_academico,$convocatoria));
	 			
		return $query->row()->FECHA;		
	}
	
	
	/**
	* Función que devuelve el estado de equivalencia o NULL
	**/
	function getEstadoEquivalencia($ano_academico, $convocatoria,$dni_pasaporte)
    {
	
		$sqlquery =" SELECT ESTADO_SOLICITUD
		              FROM PM_CAB_PREINSCRIPCION 				  
					  WHERE dni_pasaporte = ? and ano_academico = ? and convocatoria = ? "; 
		
    	
		$query=$this -> db ->query($sqlquery,array($dni_pasaporte,$ano_academico,$convocatoria));
		return $query->row()->ESTADO_SOLICITUD;	
	
	}

	
	
	/**
	 * Hace una consulta para saber si ya ha tiene estudios de origen extranjero o no	 
     * @param $ano_academico
     * @param $convocatoria
	 * @param $user debe ser distinto de null
	 * @return unknown_type
	 */
	function isExtranjero($ano_academico, $convocatoria,$user ){
		
		$sqlquery="SELECT dni_pasaporte 
		           FROM pm_cab_preinscripcion 
				   WHERE dni_pasaporte = ? and
				         ano_academico =  ? and
						 convocatoria = ?  and
						 cod_estudios_mec = '90990000000' ";
	 	
		//('debug', $sqlquery);
		
		$query=$this -> db ->query($sqlquery,array($user,$ano_academico,$convocatoria));
	 	return $query->row();
	
	}
	
	function modificarAllDatosAcademicos($ano_academico, $convocatoria,$data)
	{	

        if (isset($data['FECHA_PAGO'])){
			$this->db->set('FECHA_PAGO',"to_date('".$data['FECHA_PAGO']."','dd/mm/yyyy')",false);
			unset($data['FECHA_PAGO']);
		}	
	
		
		return $this->db->update('PM_CAB_PREINSCRIPCION', $data, array('ANO_ACADEMICO'=>$ano_academico,'CONVOCATORIA'=>$convocatoria));
  	}
	
	
	/**
	 * Nos devuelve el valor de bloqueo
	 * devuelve 0 o 1 filas
	 * @param $ano_academico
	 * @param $convocatoria
	 * @param $user 
	 * @return unknown_type
	 */
	function getBloqueo($ano_academico, $convocatoria,$user){
				
		$sqlquery="SELECT nivel_bloqueo
		           FROM pm_cab_preinscripcion 
				   WHERE dni_pasaporte = ? and 
				         ano_academico = ? and 
						 convocatoria = ?  ";
		
		$query=$this -> db ->query($sqlquery,array($user,$ano_academico,$convocatoria));
	 	
	 	if ($query->num_rows()==1){
	 		log_message('info',">>Datos Academicos bloqueados :".$user);
	 	}else{
	 		log_message('info',">>Datos Academicos NO bloqueados::".$user);
	 	}
	 	
	 	//return $query->row()->NIVEL_BLOQUEO;
		return $query->row();
		
	}
	
	/**
	 * Devuelvo si un  país es de IEEE
	 * @return string
	 */
	function perteneceEEES($cod_pais){
	
	    $sql = "SELECT ind_pertenece_eees 
		             FROM paises 
		             WHERE cod_pais=?  and indbaja != 'S'"; 
		        
		$query=$this -> db ->query($sql,array($cod_pais));
		return $query->row()->IND_PERTENECE_EEES;
	}
	
	
	/**
	* Función que devuelve campo observaciones
	**/
	function getObservaciones($ano_academico, $convocatoria,$dni_pasaporte)
    {
	
		$sqlquery =" SELECT observaciones
		              FROM PM_CAB_PREINSCRIPCION 				  
					  WHERE dni_pasaporte = ? and ano_academico = ? and convocatoria = ? "; 
		
    	
		$query=$this -> db ->query($sqlquery,array($dni_pasaporte,$ano_academico,$convocatoria));
		return $query->row()->OBSERVACIONES;	
	
	}
}
?>