﻿<?php
class Datospersonales_model extends CI_Model {

	function __construct(){
		parent::__construct();	
		$this->load->database();   
		
	}


   /**
	 * Hace una consulta para saber si ya ha realizado previamente una solicitud de preinscripcion para el año y convocatoria en curso
	 * devuelve 0 o 1 filas
	 * @param $user debe ser distinto de null
     * @param $ano_academico
     * @param $convocatoria
	 * @return unknown_type
	 */
	function existeSolicitante($user, $ano_academico, $convocatoria){
				
		$sqlquery="SELECT dni_pasaporte ,tipo_documento,ape1_alumno,ape2_alumno,nomb_alumno 
		          FROM pm_solicitantes 
				  WHERE dni_pasaporte = ? and
				        ano_academico = ? and
						convocatoria = ?";
	 	
		
		$query=$this -> db ->query($sqlquery,array($user,$ano_academico,$convocatoria));
	
	 	if ($query->num_rows()==1){
	 		log_message('info',">>Solicitante antiguo::".$user);
	 	}else{
	 		log_message('info',">>Solicitante nuevo::".$user);
	 	}
	 	
	 	return $query->row();
		
	}
	
	
	
	/**
	 * Hace una consulta para saber si es alumno uva o no (si existe en personas_actual)
	 * devuelve 0 o 1 filas
	 * @param $user debe ser distinto de null
	 * @return unknown_type
	 */
	function alumnoUva($user){
				
		$sqlquery="SELECT dni_pasaporte ,tipo_doc_id as tipo_documento,ape1_alumno,ape2_alumno,nomb_alumno 
		          FROM personas_actual 
				  WHERE dni_pasaporte = ?";
	 	
//		log_message('debug', $sqlquery);
		
		$query=$this -> db ->query($sqlquery,array($user));
	 	
	 	if ($query->num_rows()==1){
	 		log_message('info',">>Solicitante alumno Uva::".$user);
	 	}else{
	 		log_message('info',">>Solicitante alumno NO Uva::".$user);
	 	}
	 	
	 	return $query->row();
		
		
	}
	
	
	/**
	 * Lista de paises
	 * @return unknown_type
	 */
	function listarPaises(){
	
	    $sqlquery = "SELECT cod_pais, denominacion_1 
		             FROM paises 
					 WHERE indbaja != 'S'
					 ORDER BY denominacion_1";
		$query = $this->db->query($sqlquery);
		
		return $query->result();
	}
	
	
	/**
	 * Lista de provincias excepto Desconocida, Extranjera
	 * @return unknown_type
	 */
	function listarProvincias(){
	
	    $sqlquery = "SELECT cod_provincia, denominacion_1 
		             FROM provincias 
					 WHERE cod_provincia not in ('99','98') 
					 ORDER BY denominacion_1";
		$query = $this->db->query($sqlquery);
		
		return $query->result();		
	}
	
	
	/**
	 * Lista de codigos postales excepto 99999- Desconocida
	 * @return unknown_type
	 */
	function listarCodigosPostales(){
	
	    $sqlquery = "SELECT cod_postal, localizacion 
		             FROM codigos_postales 
					 WHERE cod_postal != '99999' 
					 ORDER BY localizacion";
		$query = $this->db->query($sqlquery);
		
		return $query->result();
			
	}
	
	
	/**
	 * Lista de localidades dada una provincia
	 * @param $provincia
	 * @return unknown_type
	 */
    function localidades($provincia)
    {
		$sqlquery="SELECT distinct localizacion 
		           FROM codigos_postales 
				   WHERE cod_provincia = ? ORDER BY localizacion";
	 	
//		log_message('debug', $sqlquery);	
		$query=$this -> db ->query($sqlquery,array($provincia));
	 	
	 	return $query->result();
		
    }
	
	
	/**
	 * Lista de codigos postales dada una provincia y una localidad
	 * @param $provincia
	 * @param $localidad
	 * @return unknown_type
	 */
    function codigosPostales($provincia,$localidad)
    {
				
		$sqlquery = "SELECT distinct cod_postal 
		              FROM codigos_postales 
					  WHERE cod_provincia = ? and 
					        localizacion = ? ORDER BY cod_postal";
					
	   //log_message('debug', $sqlquery);					

		$query=$this -> db ->query($sqlquery,array($provincia,$localidad));
	
		return $query->result();
    }
	
		
	
	
	/**
	 * Inserta un nuevo solicitante 
	 * @param $data
	 * @return unknown_type
	 */	
	function insertarSolicitante($data)
	{				
	   
		$this->db->set('FECHA_NAC_ALUMNO',"to_date('".$data['FECHA_NAC_ALUMNO']."','dd/mm/yyyy')",false);
		
		unset($data['FECHA_NAC_ALUMNO']);		
		
		return $this->db->insert('PM_SOLICITANTES', $data);
  	}

		
	/**
	 * Modifica un nuevo solicitante 
	 * @param $ano_academico
	 * @param $convocatoria
	 * @param $dni_pasaporte
	 * @param $data	
	 * @return unknown_type
	 */	
	function modificarSolicitante($ano_academico, $convocatoria,$dni_pasaporte,$data)
	{				
		$this->db->set('FECHA_NAC_ALUMNO',"to_date('".$data['FECHA_NAC_ALUMNO']."','dd/mm/yyyy')",false);
		
		unset($data['FECHA_NAC_ALUMNO']);		
		
		return $this->db->update('PM_SOLICITANTES', $data, array('DNI_PASAPORTE'=>$dni_pasaporte,'ANO_ACADEMICO'=>$ano_academico,'CONVOCATORIA'=>$convocatoria));
  	}
	
	
	/**
	 * Calcula el ord_localizacion dado un codigo_postal,provincia y una localidad
	 * @param $codigopostal
	 * @param $provincia
	 * @param $localidad
	 * @return unknown_type
	 */
    function calculaOrdLocaliz($codigopostal,$provincia,$localidad)
    {

         $sqlquery = "SELECT orden_localizacion 
		              FROM codigos_postales 
					  WHERE cod_provincia = ? and 
					        localizacion = ? and
							cod_postal = ? ";
							
		$query=$this -> db ->query($sqlquery,array($provincia,$localidad,$codigopostal));
		//log_message('debug', $sqlquery);
		
		 $valor = $query->row();
  		 return $valor->ORDEN_LOCALIZACION;
	}
	
	
	/**
	 *  Obtengo datos personales de la Uva para un dni (tabla personas_actual)
	 * @param $dni_pasaporte
	 * @return unknown_type
	 */
    function getdatosUva($dni_pasaporte)
    {
	
		log_message('debug','llamo a getDatosUva');
		
		$sqlquery=" SELECT a.* ,a.tipo_doc_id as tipo_documento, to_char(a.fecha_nac_alumno, 'dd/mm/yyyy') as fecha_nac_alumno,
		                   b.localizacion as localidad1_habit, c.localizacion AS localidad1_nacim
		            FROM personas_Actual a
                    LEFT JOIN codigos_postales b ON a.cod_post_habit = b.cod_postal  AND ord_localiz_habit = b.orden_localizacion
                    LEFT JOIN codigos_postales c ON a.cod_post_nacim = c.cod_postal AND ord_localiz_nacim = c.orden_localizacion where  a.dni_pasaporte = ? ";
		
    	//log_message('debug',$sqlquery);		
		$query=$this -> db ->query($sqlquery,array($dni_pasaporte));
		
		return $query->row();
		
	
	}
	
	
	/**
	 *  Obtengo datos personales de un solicitante para un dni (tabla pm_solicitantes)
	 * @param $ano_academico
	 * @param $convocatoria
	 * @param $dni_pasaporte
	 * @return unknown_type
	 */
    function getdatosSolicitante($ano_academico, $convocatoria,$dni_pasaporte)
    {
	
		log_message('debug','llamo a getDatosSolicitante');
		
		$sqlquery=" SELECT a.* , to_char(a.fecha_nac_alumno, 'dd/mm/yyyy') as fecha_nac_alumno,
		            CASE WHEN a.cod_post_habit = '99999' THEN a.localidad1_habit 
					  ELSE b.localizacion 
				    END as localidad1_habit,  
                    CASE WHEN a.cod_post_nacim = '99999' THEN a.localidad1_nacim 
					  ELSE c.localizacion 
				    END as localidad1_nacim 					              					
		            FROM pm_solicitantes a
                    LEFT JOIN codigos_postales b ON a.cod_post_habit = b.cod_postal  AND ord_localiz_habit = b.orden_localizacion
                    LEFT JOIN codigos_postales c ON a.cod_post_nacim = c.cod_postal
					WHERE  a.dni_pasaporte = ? and
					       a.ano_academico = ? and a.convocatoria = ?";
		
    	//log_message('debug',$sqlquery);		
		$query=$this -> db ->query($sqlquery,array($dni_pasaporte,$ano_academico, $convocatoria));
		
		return $query->row();
		
	
	}
	
	
	/**
	 * Devuelvo el nombre de un país
	 * @return string
	 */
	function getPais($cod_pais){
	
	    $sql = "SELECT cod_pais, denominacion_1 
		             FROM paises 
		             WHERE cod_pais=? "; 
		        
		$query=$this -> db ->query($sql,array($cod_pais));
		return $query->row()->DENOMINACION_1;
	}
	
	
	/**
	 * 
	 */
	function getProvincia($cod_provincia){
	
	    $sql = "SELECT cod_provincia, denominacion_1 
		             FROM provincias WHERE cod_provincia=?";
		
		$query=$this -> db ->query($sql,array($cod_provincia));
		return $query->row()->DENOMINACION_1;		
	}
	/**
	* 
	*/
	function getLocalidad($cod_provincia,$cod_postal,$orden_localizacion){
		log_message("debug","___llamadaGetLocalidad:".$cod_provincia."_".$cod_postal."_".$orden_localizacion);
	    $sql = "SELECT localizacion 
		           FROM codigos_postales 
				   WHERE cod_provincia =? and cod_postal=? and orden_localizacion=?";
		
		$query=$this -> db ->query($sql,array($cod_provincia,$cod_postal,$orden_localizacion));
		return $query->row()->LOCALIZACION;		
	}

		
	
}
?>